referrerpolicy=no-referrer-when-downgrade

InitialPsmConfig

Trait InitialPsmConfig 

pub trait InitialPsmConfig<T: Config> {
    // Required methods
    fn max_psm_debt_of_total() -> Permill;
    fn asset_configs() -> BTreeMap<T::AssetId, (Permill, Permill, Permill)>;
}
Configuration trait for initial PSM parameters.

Implement this trait in your runtime to provide the initial values used by InitializePsm.

Required Methods

fn max_psm_debt_of_total() -> Permill

Max PSM debt as a fraction of MaximumIssuance.

fn asset_configs() -> BTreeMap<T::AssetId, (Permill, Permill, Permill)>

Per-asset configuration:

  • minting fee
  • redemption fee
  • asset ceiling weight

Keys also define the set of approved external assets.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors